@@ -1,6 +1,9 @@
-#![crate_name = "zoneinfo_compiled"]
-#![crate_type = "rlib"]
-#![crate_type = "dylib"]
+#![warn(missing_copy_implementations)]
+//#![warn(missing_docs)]
+#![warn(nonstandard_style)]
+#![warn(trivial_numeric_casts)]
+#![warn(unreachable_pub)]
+#![warn(unused)]
 
 //! This is a library for parsing compiled zoneinfo files.
 
@@ -17,6 +20,7 @@ use datetime::zone::runtime::{OwnedTimeZone, OwnedFixedTimespanSet};
 pub mod parser;
 pub use parser::Result;
 
+
 pub trait CompiledData {
     fn parse(input: Vec<u8>) -> Result<TimeZone>;
 
@@ -57,14 +61,14 @@ pub struct TZData {
 
 
 /// A leap second specification.
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Copy, Clone)]
 pub struct LeapSecond {
 
     /// Unix timestamp at which a leap second occurs.
     pub timestamp: i32,
 
     /// Number of leap seconds to be added.
-    pub leap_second_count: u32,
+    pub leap_second_count: i32,
 }
 
 
@@ -128,8 +132,9 @@ pub fn cook(tz: parser::TZData) -> Result<TZData> {
                                    .take_while(|&c| c != 0)
                                    .collect();
 
-        let std_flag = tz.standard_flags.get(i).copied().unwrap_or_default() != 0;
-        let gmt_flag = tz.gmt_flags.get(i).copied().unwrap_or_default() != 0;
+        // (TODO: move to ‘copied’ when the library supports that Rust version)
+        let std_flag = tz.standard_flags.get(i).cloned().unwrap_or_default() != 0;
+        let gmt_flag = tz.gmt_flags.get(i).cloned().unwrap_or_default() != 0;
 
         let info = LocalTimeType {
             name:             String::from_utf8(name_bytes)?,
@@ -167,32 +172,29 @@ pub fn cook(tz: parser::TZData) -> Result<TZData> {
     // transitions list.
 
     if transitions.is_empty() {
-        Ok(TZData {
-            time_zone: OwnedTimeZone {
-                name: None,
-                fixed_timespans: OwnedFixedTimespanSet {
-                    first: local_time_types[0].to_fixed_timespan(),
-                    rest: Vec::new(),
-                },
+        let time_zone = OwnedTimeZone {
+            name: None,
+            fixed_timespans: OwnedFixedTimespanSet {
+                first: local_time_types[0].to_fixed_timespan(),
+                rest: Vec::new(),
             },
-            leap_seconds: leap_seconds,
-        })
+        };
+
+        Ok(TZData { time_zone, leap_seconds })
     }
     else {
         // We don’t care about the timestamp that the first transition happens
         // at: we assume it to have been in effect forever.
         let first = transitions.remove(0);
+        let time_zone = OwnedTimeZone {
+            name: None,
+            fixed_timespans: OwnedFixedTimespanSet {
+                first: first.1,
+                rest: transitions,
+            }
+        };
 
-        Ok(TZData {
-            time_zone: OwnedTimeZone {
-                name: None,
-                fixed_timespans: OwnedFixedTimespanSet {
-                    first: first.1,
-                    rest: transitions,
-                }
-            },
-            leap_seconds: leap_seconds,
-        })
+        Ok(TZData { time_zone, leap_seconds })
     }
 }
 
