@@ -11,13 +11,13 @@
 
 use byteorder::{ReadBytesExt, BigEndian};
 
-use std::error;
+use std::error::Error as ErrorTrait;
 use std::fmt;
 use std::io::{Cursor, Read};
 use std::result;
 
 
-#[derive(Debug, PartialEq, Eq, Clone)]
+#[derive(Debug, PartialEq, Eq, Copy, Clone)]
 pub struct Header {
 
     /// The version of this file's format - either '\0', or '2', or '3'.
@@ -49,7 +49,7 @@ pub struct Header {
 }
 
 
-#[derive(Debug, PartialEq, Eq, Clone)]
+#[derive(Debug, PartialEq, Eq, Copy, Clone)]
 pub struct TransitionData {
 
     /// The time at which the rules for computing local time change.
@@ -60,7 +60,7 @@ pub struct TransitionData {
 }
 
 
-#[derive(Debug, PartialEq, Eq, Clone)]
+#[derive(Debug, PartialEq, Eq, Copy, Clone)]
 pub struct LocalTimeTypeData {
 
     /// Number of seconds to be added to Universal Time.
@@ -78,14 +78,14 @@ pub struct LocalTimeTypeData {
 }
 
 
-#[derive(Debug, PartialEq, Eq, Clone)]
+#[derive(Debug, PartialEq, Eq, Copy, Clone)]
 pub struct LeapSecondData {
 
     /// The time, as a number of seconds, at which a leap second occurs.
     pub timestamp: i32,
 
     /// Number of leap seconds to be added.
-    pub leap_second_count: u32,
+    pub leap_second_count: i32,
 }
 
 
@@ -99,7 +99,7 @@ pub struct LeapSecondData {
 /// file could try to read *gigabytes* of data while trying to read time zone
 /// information. To prevent this, reasonable defaults are set, although they
 /// can be turned off if necessary.
-#[derive(Debug, Clone)]
+#[derive(Debug, Copy, Clone)]
 pub struct Limits {
 
     /// Maximum number of transition structures
@@ -256,7 +256,7 @@ impl Parser {
         for _ in 0 .. count {
             buf.push(LeapSecondData {
                 timestamp:          self.cursor.read_i32::<BigEndian>()?,
-                leap_second_count:  self.cursor.read_u32::<BigEndian>()?,
+                leap_second_count:  self.cursor.read_i32::<BigEndian>()?,
             });
         }
         Ok(buf)
@@ -268,9 +268,9 @@ impl Parser {
 /// This is used to return a bunch of errors early, including a limit being
 /// reached, the buffer failed to be read from, or a string not being valid
 /// UTF-8.
-pub type Result<T> = result::Result<T, Box<error::Error>>;
+pub type Result<T> = result::Result<T, Box<dyn ErrorTrait>>;
 
-#[derive(Debug)]
+#[derive(Debug, Copy, Clone)]
 pub enum Error {
 
     /// The error when the first four bytes of the buffer weren't what they
@@ -297,7 +297,7 @@ pub enum Error {
     NoTransitions,
 }
 
-impl error::Error for Error {
+impl ErrorTrait for Error {
     fn description(&self) -> &str {
         match *self {
             Error::InvalidMagicNumber   => "invalid magic number",
@@ -326,7 +326,7 @@ impl fmt::Display for Error {
 
 /// A description of which value is being read. This gets used solely for
 /// error reporting.
-#[derive(Debug)]
+#[derive(Debug, Copy, Clone)]
 pub enum Structures {
     Transitions,
     LocalTimeTypes,
@@ -374,8 +374,8 @@ pub fn parse(buf: Vec<u8>, limits: Limits) -> Result<TZData> {
 
     let transitions    = parser.read_transition_data(header.num_transitions as usize)?;
     let time_info      = parser.read_local_time_type_data(header.num_local_time_types as usize)?;
-    let leap_seconds   = parser.read_leap_second_data(header.num_leap_seconds as usize)?;
     let strings        = parser.read_octets(header.num_abbr_chars as usize)?;
+    let leap_seconds   = parser.read_leap_second_data(header.num_leap_seconds as usize)?;
     let standard_flags = parser.read_octets(header.num_standard_flags as usize)?;
     let gmt_flags      = parser.read_octets(header.num_gmt_flags as usize)?;
 
